@@ -7,7 +7,7 @@ with the Claude LLM.
 
 from meta_ads_mcp.core.server import main
 
-__version__ = "0.9.0"
+__version__ = "0.10.5"
 
 __all__ = [
     'get_ad_accounts',
@@ -29,7 +29,7 @@ __all__ = [
     'main',
     'search_interests',
     'get_interest_suggestions',
-    'validate_interests',
+    'estimate_audience_size',
     'search_behaviors',
     'search_demographics',
     'search_geo_locations'
@@ -56,7 +56,7 @@ from .core import (
     main,
     search_interests,
     get_interest_suggestions,
-    validate_interests,
+    estimate_audience_size,
     search_behaviors,
     search_demographics,
     search_geo_locations
